@@ -28,5 +28,10 @@ git add botfinder/version.py
 git commit -m "Version $NEW_VERSION"
 git tag -a v$NEW_VERSION -m "Version $NEW_VERSION"
 
+# update changelog
+gitchangelog > CHANGELOG.md
+git add CHANGELOG.md
+git commit --amend -m "Version $NEW_VERSION"
+
 python setup.py sdist bdist_wheel
 twine upload dist/*
\ No newline at end of file
